@@ -231,7 +231,7 @@ class SmappeeMqtt(threading.Thread):
 class SmappeeLocalMqtt(threading.Thread):
     """Smappee local MQTT wrapper."""
 
-    def __init__(self, serial_number):
+    def __init__(self, serial_number=None):
         self._client = None
         self.service_location = None
         self._serial_number = serial_number
@@ -328,6 +328,8 @@ class SmappeeLocalMqtt(threading.Thread):
                 pass
             elif message.topic.endswith('/aggregated'):
                 pass
+            elif message.topic.endswith('/aggregatedGW'):
+                pass
             elif message.topic.endswith('/aggregatedSwitch'):
                 pass
             elif message.topic.endswith('/etc/measuredvalues'):
@@ -359,7 +361,7 @@ class SmappeeLocalMqtt(threading.Thread):
                 actuator_id = int(message.topic.split('/')[-2])
                 p = str(message.payload.decode('utf-8')).replace("\'", "\"")
                 self.actuators_state[actuator_id] = json.loads(p).get('value')
-            else:
+            elif config['MQTT']['discovery']:
                 print('Processing MQTT message from topic {0} with value {1}'.format(message.topic, message.payload))
 
         except Exception:
