@@ -4,7 +4,6 @@ from .actuator import SmappeeActuator
 from .appliance import SmappeeAppliance
 from .measurement import SmappeeMeasurement
 from .sensor import SmappeeSensor
-from .smart_device import SmappeeSmartDevice
 from cachetools import TTLCache
 
 
@@ -36,12 +35,11 @@ class SmappeeServiceLocation(object):
         # presence
         self._presence = None
 
-        # dicts to hold appliances, smart switches, ct details and smart devices by id
+        # dicts to hold appliances, smart switches and ct details by id
         self._appliances = {}
         self._actuators = {}
         self._sensors = {}
         self._measurements = {}
-        self._smart_devices = {}
 
         # realtime values
         self._realtime_values = {
@@ -90,8 +88,53 @@ class SmappeeServiceLocation(object):
             self._service_location_uuid = 0
 
             if self._device_serial_number.startswith('50'):
+                self.smappee_api.service_location = self
                 self._has_reactive_value = True
                 self._phase_type = self.smappee_api.phase_type
+
+                for switch in self.smappee_api.switch_sensors:
+                    current_state = False
+                    if self.smappee_api.actuators_state.get(switch['nodeId']) == 'ON':
+                        current_state = True
+
+                    self._add_actuator(
+                        id=switch['nodeId'],
+                        name=switch['name'],
+                        serialnumber=switch['serialNumber'],
+                        state_values=[
+                            {'id': 'ON_ON', 'name': 'on', 'current': True if current_state else False},
+                            {'id': 'OFF_OFF', 'name': 'off', 'current': False if current_state else True}
+                        ],
+                        connection_state=self.smappee_api.actuators_connection_state.get(switch['nodeId'], 'CONNECTED'),
+                        actuator_type='SWITCH'
+                    )
+
+                for plug in self.smappee_api.smart_plugs:
+                    current_state = False
+                    if self.smappee_api.actuators_state.get(plug['nodeId']) == 'ON':
+                        current_state = True
+
+                    self._add_actuator(
+                        id=plug['nodeId'],
+                        name=plug['name'],
+                        serialnumber=None,
+                        state_values=[
+                            {'id': 'ON_ON', 'name': 'on', 'current': True if current_state else False},
+                            {'id': 'OFF_OFF', 'name': 'off', 'current': False if current_state else True}
+                        ],
+                        connection_state='CONNECTED',
+                        actuator_type='COMFORT_PLUG'
+                    )
+
+                for measurement_name, measurement_index in self.smappee_api.measurements.items():
+                    self._add_measurement(
+                        id=min(measurement_index),
+                        name=measurement_name,
+                        type='CT',
+                        subcircuitType=None,
+                        channels=[{'consumptionIndex': m} for m in measurement_index]
+                    )
+
             else:
                 # Load actuators
                 self.smappee_api.logon()
@@ -387,19 +430,6 @@ class SmappeeServiceLocation(object):
                                                    subcircuit_type=subcircuitType,
                                                    channels=channels)
 
-    @property
-    def smart_devices(self):
-        return self._smart_devices
-
-    def _add_smart_device(self, uuid, name, category, implementation, minCurrent, maxCurrent, measurements):
-        self.smart_devices[uuid] = SmappeeSmartDevice(uuid=uuid,
-                                                      name=name,
-                                                      category=category,
-                                                      implementation=implementation,
-                                                      minCurrent=minCurrent,
-                                                      maxCurrent=maxCurrent,
-                                                      measurements=measurements)
-
     @property
     def total_power(self):
         return self._realtime_values.get('total_power')
@@ -518,17 +548,11 @@ class SmappeeServiceLocation(object):
             for _, measurement in self.measurements.items():
                 measurement.update_current(current=current_data)
 
-        # update smart devices power
-        # for uuid, smart_device in self.smart_devices.items():
-        #     smart_device.update_active(active=active_power_data)
-        #     smart_device.update_reactive(reactive=reactive_power_data)
-        #     smart_device.update_current(current=current_data)
-
     def _update_realtime_data(self, realtime_data):
         # Use incoming realtime data (through local MQTT connection)
         self.total_power = realtime_data.get('totalPower')
         self.reactive_power = realtime_data.get('totalReactivePower')
-        self.phase_voltages = realtime_data.get('voltages')
+        self.phase_voltages = [v.get('voltage', 0) for v in realtime_data.get('voltages')]
 
         active_power_data, current_data = {}, {}
         for channel_power in realtime_data.get('channelPowers'):
@@ -615,10 +639,7 @@ class SmappeeServiceLocation(object):
 
     def update_trends_and_appliance_states(self, ):
         if self.local_polling and self._device_serial_number.startswith('50'):
-            self._realtime_values['total_power'] = self.smappee_api.realtime.get('totalPower', 0)
-            self._realtime_values['total_reactive_power'] = self.smappee_api.realtime.get('totalReactivePower', 0)
-            self._realtime_values['phase_voltages'] = [v.get('voltage', 0) for v in self.smappee_api.realtime.get('voltages', [{}, {}, {}])]
-
+            pass
         elif self.local_polling:
             # Active power
             tp = self.smappee_api.active_power()
